GanttChartLayout class

Layout engine for Gantt charts

Constructors

GanttChartLayout({MermaidDeviceConfig? deviceConfig})
Creates a Gantt chart layout
const

Properties

deviceConfig MermaidDeviceConfig?
Responsive device configuration
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

computeLayout(GanttChartData ganttData, MermaidStyle style, Size availableSize) Size
Computes the size needed to render the Gantt chart
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited