KanbanColumn class

Represents a column in Kanban board

Constructors

KanbanColumn({required String id, required String title, required List<KanbanTask> tasks, int? wipLimit})
Creates a Kanban column
const

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
Column identifier
final
isOverLimit bool
Returns true if column is over WIP limit
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tasks List<KanbanTask>
Tasks in this column
final
title String
Column display title
final
wipLimit int?
Work-in-progress limit
final

Methods

copyWith({String? id, String? title, List<KanbanTask>? tasks, int? wipLimit}) KanbanColumn
Creates a copy with modified properties
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override