MermaidThemes class

Predefined themes for Mermaid diagrams

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

dark MermaidStyle
Dark theme
final
forest MermaidStyle
Forest (green) theme
final
neutral MermaidStyle
Neutral (gray) theme
final

Static Methods

getTheme(MermaidThemeMode mode) MermaidStyle
Gets a theme by mode

Constants

light → const MermaidStyle
Default light theme