PieChartLayout class
Layout engine for pie charts
Constructors
- PieChartLayout({MermaidDeviceConfig? deviceConfig})
-
Creates a pie chart layout
const
Properties
- deviceConfig → MermaidDeviceConfig?
-
Responsive device configuration
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
computeLayout(
PieChartData pieData, MermaidStyle style, Size availableSize) → Size - Computes the size needed to render the pie chart
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited