PieChartParser class

Parser for Mermaid pie chart diagrams

Parses pie chart syntax like:

pie
    title My Pie Chart
    "Dogs" : 386
    "Cats" : 85
    "Rats" : 15

Or with showData:

pie showData
    title My Pie Chart
    "Dogs" : 386
    "Cats" : 85

Constructors

PieChartParser()
Creates a pie chart parser
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(List<String> lines) → (MermaidDiagramData, PieChartData)?
Parses pie chart diagram from cleaned lines
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited