MermaidNode class
Represents a node in a Mermaid diagram
- Implementers
Constructors
Properties
- className → String?
-
CSS class name for styling
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- height ↔ double
-
Height after measurement
getter/setter pair
- id → String
-
Unique identifier for this node
final
- label → String
-
Display label
final
- link → String?
-
Optional link URL
final
- order ↔ int
-
Order within the layer
getter/setter pair
- rank ↔ int
-
Layer/rank in the graph (for hierarchical layout)
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → NodeShape
-
Shape of the node
final
- style → NodeStyle?
-
Custom inline style
final
- tooltip → String?
-
Optional tooltip text
final
- width ↔ double
-
Width after measurement
getter/setter pair
- x ↔ double
-
X position after layout
getter/setter pair
- y ↔ double
-
Y position after layout
getter/setter pair
Methods
-
copyWith(
{String? id, String? label, NodeShape? shape, NodeStyle? style, String? className, String? link, String? tooltip}) → MermaidNode - Creates a copy with modified properties
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override