NodeShape enum
Shape types for nodes
Values
- rectangle → const NodeShape
-
Rectangle with square corners
text - roundedRect → const NodeShape
-
Rectangle with rounded corners (text)
- stadium → const NodeShape
-
Stadium/pill shape (
text) - diamond → const NodeShape
-
Diamond/rhombus shape {text}
- hexagon → const NodeShape
-
Hexagon shape {{text}}
- circle → const NodeShape
-
Circle shape ((text))
- parallelogram → const NodeShape
-
Parallelogram shape
/text/ - parallelogramAlt → const NodeShape
-
Parallelogram (alt) shape [\text]
- trapezoid → const NodeShape
-
Trapezoid shape [/text]
- trapezoidAlt → const NodeShape
-
Trapezoid (alt) shape
\text/ - cylinder → const NodeShape
-
Cylinder/database shape
(text) - subroutine → const NodeShape
-
Subroutine shape [
text] - asymmetric → const NodeShape
-
Asymmetric shape >text]
- doubleCircle → const NodeShape
-
Double circle (for state diagrams)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited