SequenceMessage class
Represents a message in a sequence diagram
- Inheritance
-
- Object
- MermaidEdge
- SequenceMessage
Constructors
- SequenceMessage({required String from, required String to, String? label, ArrowType arrowType = ArrowType.arrow, LineType lineType = LineType.solid, MessageType messageType = MessageType.sync, bool activate = false, bool deactivate = false})
-
Creates a sequence message
const
Properties
- activate → bool
-
Whether to activate the target
final
- animated → bool
-
Whether the edge should be animated
finalinherited
- arrowType → ArrowType
-
Type of arrow at the end
finalinherited
- bidirectional → bool
-
Whether the arrow points both ways
finalinherited
- deactivate → bool
-
Whether to deactivate the target
final
- from → String
-
Source node ID
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSubgraphEdge → bool
-
Whether this edge connects subgraphs (not individual nodes)
finalinherited
- label → String?
-
Optional label on the edge
finalinherited
- lineType → LineType
-
Type of line
finalinherited
- messageType → MessageType
-
Type of message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → EdgeStyle?
-
Custom style
finalinherited
- to → String
-
Target node ID
finalinherited
Methods
-
copyWith(
{String? from, String? to, String? label, ArrowType? arrowType, LineType? lineType, EdgeStyle? style, bool? animated, bool? bidirectional, bool? isSubgraphEdge}) → MermaidEdge -
Creates a copy with modified properties
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited